@@ -8,7 +8,7 @@ use crate::{
 use swc_common::{util::take::Take, Spanned, DUMMY_SP};
 use swc_ecma_ast::*;
 use swc_ecma_utils::{prepend, undefined, StmtLike};
-use swc_ecma_visit::{noop_visit_type, Node, Visit, VisitWith};
+use swc_ecma_visit::{noop_visit_type, Visit, VisitWith};
 
 /// Methods related to the option `if_return`. All methods are noop if
 /// `if_return` is false.
@@ -223,7 +223,8 @@ where
             let stmts = &stmts[skip..=last_idx];
             let return_count: usize = stmts.iter().map(|v| count_leaping_returns(v)).sum();
 
-            // There's no return statment so merging requires injecting unnecessary `void 0`
+            // There's no return statement so merging requires injecting unnecessary `void
+            // 0`
             if return_count == 0 {
                 tracing::trace!("if_return: [x] Aborting because we failed to find return");
                 return;
@@ -327,7 +328,7 @@ where
                 span: DUMMY_SP,
                 stmts: stmts.clone(),
             };
-            tracing::trace!("if_return: {}", dump(&block))
+            tracing::trace!("if_return: {}", dump(&block, false))
         }
         self.changed = true;
 
@@ -564,7 +565,7 @@ where
     N: VisitWith<ReturnFinder>,
 {
     let mut v = ReturnFinder::default();
-    n.visit_with(&Invalid { span: DUMMY_SP }, &mut v);
+    n.visit_with(&mut v);
     v.count
 }
 
@@ -576,13 +577,13 @@ pub(super) struct ReturnFinder {
 impl Visit for ReturnFinder {
     noop_visit_type!();
 
-    fn visit_return_stmt(&mut self, n: &ReturnStmt, _: &dyn Node) {
+    fn visit_return_stmt(&mut self, n: &ReturnStmt) {
         n.visit_children_with(self);
         self.count += 1;
     }
 
-    fn visit_function(&mut self, _: &Function, _: &dyn Node) {}
-    fn visit_arrow_expr(&mut self, _: &ArrowExpr, _: &dyn Node) {}
+    fn visit_function(&mut self, _: &Function) {}
+    fn visit_arrow_expr(&mut self, _: &ArrowExpr) {}
 }
 
 fn always_terminates_with_return_arg(s: &Stmt) -> bool {
@@ -646,7 +647,7 @@ fn can_merge_as_if_return(s: &Stmt) -> bool {
     let c = cost(s);
 
     if cfg!(feature = "debug") {
-        tracing::trace!("merging cost of `{}` = {:?}", dump(s), c);
+        tracing::trace!("merging cost of `{}` = {:?}", dump(s, false), c);
     }
 
     c.unwrap_or(0) < 0
